summaryrefslogtreecommitdiff
path: root/dbaccess/source/ui/inc/RelationControl.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'dbaccess/source/ui/inc/RelationControl.hxx')
-rw-r--r--dbaccess/source/ui/inc/RelationControl.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/dbaccess/source/ui/inc/RelationControl.hxx b/dbaccess/source/ui/inc/RelationControl.hxx
index 55983b1dff6e..62b812f4f98f 100644
--- a/dbaccess/source/ui/inc/RelationControl.hxx
+++ b/dbaccess/source/ui/inc/RelationControl.hxx
@@ -74,7 +74,7 @@ namespace dbaui
/** enables the relation control
*
* \param _bEnable when TRUE enables it, otherwise disable it.
*/
void enableRelation(bool _bEnable);
@@ -90,7 +90,7 @@ namespace dbaui
void lateUIInit(Window* _pTableSeparator = NULL);
void lateInit();
- BOOL SaveModified();
+ sal_Bool SaveModified();
TTableWindowData::value_type getReferencingTable() const;
@@ -74,7 +74,7 @@ namespace dbaui
/** enables the relation control
*
- * \param _bEnable when TRUE enables it, otherwise disable it.
+ * \param _bEnable when sal_True enables it, otherwise disable it.
*/
void enableRelation(bool _bEnable);